==> kubernetes-model-autoscaling-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MetricSpecBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecBuilder>{
  public MetricSpecBuilder() {
    this(false);
  }
  public MetricSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MetricSpec(), validationEnabled);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MetricSpec(), validationEnabled);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance) {
    this(fluent, instance, false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainerResource(instance.getContainerResource()); 
    fluent.withExternal(instance.getExternal()); 
    fluent.withObject(instance.getObject()); 
    fluent.withPods(instance.getPods()); 
    fluent.withResource(instance.getResource()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance) {
    this(instance,false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainerResource(instance.getContainerResource()); 
    this.withExternal(instance.getExternal()); 
    this.withObject(instance.getObject()); 
    this.withPods(instance.getPods()); 
    this.withResource(instance.getResource()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec build() {
    MetricSpec buildable = new MetricSpec(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MetricSpecBuilder that = (MetricSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/MetricSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MetricSpecBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecBuilder>{
  public MetricSpecBuilder() {
    this(false);
  }
  public MetricSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MetricSpec(), validationEnabled);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MetricSpec(), validationEnabled);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance) {
    this(fluent, instance, false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withContainerResource(instance.getContainerResource()); 
    fluent.withExternal(instance.getExternal()); 
    fluent.withObject(instance.getObject()); 
    fluent.withPods(instance.getPods()); 
    fluent.withResource(instance.getResource()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance) {
    this(instance,false);
  }
  public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withContainerResource(instance.getContainerResource()); 
    this.withExternal(instance.getExternal()); 
    this.withObject(instance.getObject()); 
    this.withPods(instance.getPods()); 
    this.withResource(instance.getResource()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.MetricSpec build() {
    MetricSpec buildable = new MetricSpec(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MetricSpecBuilder that = (MetricSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
